/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 */

package uk.co.petertribble.jkstat.gui;

import uk.co.petertribble.jkstat.api.*;
import javax.swing.*;
import java.text.DecimalFormat;
import uk.co.petertribble.jingle.SpringUtilities;

/**
 * An accessory panel that graphically represents I/O activity.
 *
 * @author Peter Tribble
 */
public class AccessoryIOPanel extends KstatAccessoryPanel {

    private int iomax = 1000;
    private int kiomax = 10000;

    private DecimalFormat df = new DecimalFormat("##0.0");

    private JProgressBar jpIn;
    private JProgressBar jpOut;
    private JProgressBar jpkIn;
    private JProgressBar jpkOut;

    private ChartableKstat cks;

    /**
     * Create a panel showing the input and output traffic on the given kstat
     * that updates every interval seconds.
     *
     * @param ks an IO kstat
     * @param interval the update interval in seconds
     * @param jkstat a JKstat
     */
    public AccessoryIOPanel(Kstat ks, int interval, JKstat jkstat) {
	super(ks, interval, jkstat);

	cks = new ChartableIOKstat(jkstat, ks);

	// the meters are measured in kbytes/s, rescaled later if need be
	jpIn = new JProgressBar(0, iomax);
	jpOut = new JProgressBar(0, iomax);
	jpkIn = new JProgressBar(0, kiomax);
	jpkOut = new JProgressBar(0, kiomax);

	jpIn.setStringPainted(true);
	jpOut.setStringPainted(true);
	jpkIn.setStringPainted(true);
	jpkOut.setStringPainted(true);

	setLayout(new SpringLayout());

	add(new JLabel("reads/s"));
	add(jpIn);
	add(new JLabel("k read/s"));
	add(jpkIn);
	add(new JLabel("writes/s"));
	add(jpOut);
	add(new JLabel("k write/s"));
	add(jpkOut);
	SpringUtilities.makeCompactGrid(this, 4, 2, 6, 3, 2, 2);

	updateAccessory();

	startLoop();
    }

    @Override
    public void updateAccessory() {
	cks.update();

	double di = cks.getRate("r/s");
	double dj = cks.getRate("w/s");
	int i = (int) di;
	int j = (int) dj;
	while (i > iomax || j > iomax) {
	    iomax <<= 1;
	    jpIn.setMaximum(iomax);
	    jpOut.setMaximum(iomax);
	}
	jpIn.setValue(i);
	jpOut.setValue(j);
	jpIn.setString(df.format(di));
	jpOut.setString(df.format(dj));

	di = cks.getRate("kr/s");
	dj = cks.getRate("kw/s");
	i = (int) di;
	j = (int) dj;
	while (i > kiomax || j > kiomax) {
	    kiomax <<= 1;
	    jpkIn.setMaximum(kiomax);
	    jpkOut.setMaximum(kiomax);
	}
	jpkIn.setValue(i);
	jpkOut.setValue(j);
	jpkIn.setString(df.format(di));
	jpkOut.setString(df.format(dj));
    }
}
